slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPReset

Resets the NEP context to the initial state (prior to setup) and destroys any allocated Vecs and Mats.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPReset(NEP nep)

Collective on nep

### Input Parameter

| nep | - eigensolver context obtained from NEPCreate()

### See Also

NEPDestroy()

### Level

advanced

### Location

src/nep/interface/nepbasic.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages